@@ -3,7 +3,7 @@ extern crate test;
 extern crate jsonwebtoken as jwt;
 extern crate rustc_serialize;
 
-use jwt::{encode, decode, Algorithm};
+use jwt::{encode, decode, Algorithm, Header};
 
 #[derive(Debug, PartialEq, Clone, RustcEncodable, RustcDecodable)]
 struct Claims {
@@ -18,11 +18,11 @@ fn bench_encode(b: &mut test::Bencher) {
         company: "ACME".to_owned()
     };
 
-    b.iter(|| encode(&claim, "secret", Algorithm::HS256));
+    b.iter(|| encode(Header::default(), &claim, "secret".as_ref()));
 }
 
 #[bench]
 fn bench_decode(b: &mut test::Bencher) {
     let token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIxMjM0NTY3ODkwIiwibmFtZSI6IkpvaG4gRG9lIiwiYWRtaW4iOnRydWV9.TJVA95OrM7E2cBab30RMHrHDcEfxjoYZgeFONFh7HgQ";
-    b.iter(|| decode::<Claims>(token, "secret", Algorithm::HS256));
+    b.iter(|| decode::<Claims>(token, "secret".as_ref(), Algorithm::HS256));
 }
