@@ -131,7 +131,7 @@ pub struct TokenData<T: Part> {
 
 /// Take the payload of a JWT and sign it using the algorithm given.
 /// Returns the base64 url safe encoded of the hmac result
-fn sign(data: &str, secret: &[u8], algorithm: Algorithm) -> String {
+pub fn sign(data: &str, secret: &[u8], algorithm: Algorithm) -> String {
     fn crypt<D: Digest>(digest: D, data: &str, secret: &[u8]) -> String {
         let mut hmac = Hmac::new(digest, secret);
         hmac.input(data.as_bytes());
@@ -146,7 +146,7 @@ fn sign(data: &str, secret: &[u8], algorithm: Algorithm) -> String {
 }
 
 /// Compares the signature given with a re-computed signature
-fn verify(signature: &str, data: &str, secret: &[u8], algorithm: Algorithm) -> bool {
+pub fn verify(signature: &str, data: &str, secret: &[u8], algorithm: Algorithm) -> bool {
     fixed_time_eq(signature.as_ref(), sign(data, secret, algorithm).as_ref())
 }
 
@@ -251,6 +251,13 @@ mod tests {
         assert!(token_data.header.kid.is_none());
     }
 
+    #[test]
+    fn decode_token() {
+        let token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiJiQGIuY29tIiwiY29tcGFueSI6IkFDTUUifQ.I1BvFoHe94AFf09O6tDbcSB8-jp8w6xZqmyHIwPeSdY";
+        let claims = decode::<Claims>(token, "secret".as_ref(), Algorithm::HS256);
+        claims.unwrap();
+    }
+
     #[test]
     #[should_panic(expected = "InvalidToken")]
     fn decode_token_missing_parts() {
@@ -267,6 +274,14 @@ mod tests {
         claims.unwrap();
     }
 
+    #[test]
+    #[should_panic(expected = "WrongAlgorithmHeader")]
+    fn decode_token_wrong_algorithm() {
+        let token = "eyJhbGciOiJIUzUxMiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiJiQGIuY29tIiwiY29tcGFueSI6IkFDTUUifQ.pKscJVk7-aHxfmQKlaZxh5uhuKhGMAa-1F5IX5mfUwI";
+        let claims = decode::<Claims>(token, "secret".as_ref(), Algorithm::HS256);
+        claims.unwrap();
+    }
+
     #[test]
     fn decode_token_with_bytes_secret() {
         let token = "eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiIxMjM0NTY3ODkwIiwiY29tcGFueSI6Ikdvb2dvbCJ9.27QxgG96vpX4akKNpD1YdRGHE3_u2X35wR3EHA2eCrs";
